@@ -110,6 +110,9 @@ void __Image()
         .def("annotate", (void (Magick::Image::*)(const std::string&, const Magick::Geometry&, const Magick::GravityType) )&Magick::Image::annotate)
         .def("annotate", (void (Magick::Image::*)(const std::string&, const Magick::Geometry&, const Magick::GravityType, const double) )&Magick::Image::annotate)
         .def("annotate", (void (Magick::Image::*)(const std::string&, const Magick::GravityType) )&Magick::Image::annotate)
+#ifdef PGMAGICK_LIB_GRAPHICSMAGICK_1_3_27
+        .def("autoOrient", &Magick::Image::autoOrient)
+#endif
         .def("blur", &Magick::Image::blur, Magick_Image_blur_overloads_0_2())
 #ifdef PGMAGICK_LIB_GRAPHICSMAGICK_1_3_x
         .def("blurChannel", &Magick::Image::blurChannel, Magick_Image_blurChannel_overloads_1_3())
@@ -157,11 +160,11 @@ void __Image()
         .def("enhance", &Magick::Image::enhance)
         .def("equalize", &Magick::Image::equalize)
         .def("erase", &Magick::Image::erase)
-#ifdef PGMAGICK_LIB_IMAGEMAGICK
+#if defined(PGMAGICK_LIB_IMAGEMAGICK) || defined(PGMAGICK_LIB_GRAPHICSMAGICK_1_3_22)
         .def("extent", (void (Magick::Image::*)(const Magick::Geometry&))&Magick::Image::extent)
         .def("extent", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Color&))&Magick::Image::extent)
-        .def("extent", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::GravityType))&Magick::Image::extent)
-        .def("extent", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Color&, const Magick::GravityType))&Magick::Image::extent)
+        .def("extent", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::GravityType&))&Magick::Image::extent)
+        .def("extent", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Color&, const Magick::GravityType&))&Magick::Image::extent)
 #endif
         .def("flip", &Magick::Image::flip)
         .def("floodFillColor", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Color&) )&Magick::Image::floodFillColor)
